@@ -5,16 +5,29 @@
 #' @importFrom jsonlite flatten
 #' @param x Either a gist or commit class object or a list of either
 #' @param ... Ignored
+#' @return A data.frame or list of data.frame's
+#' @details For commits we return a single data.frame. For gists, we always 
+#' return a list so that we are returning data consistently, 
+#' regardless of variable return data. So you can always index to the main data.frame
+#' with gist metadata and file info by doing \code{result$data}, and likewise for 
+#' forks \code{result$forks} and history \code{result$history}
 #' @examples \dontrun{
+#' # from a gist object
 #' x <- as.gist('f1403260eb92f5dfa7e1')
-#' tabl(x)
+#' res <- tabl(x)
+#' res$data
+#' res$forks
+#' res$history
 #' 
 #' # from a list
 #' ss <- gists('minepublic')
 #' tabl(ss[1:3])
+#' lapply(tabl(ss[1:3]), "[[", "data")
+#' # index to data slots, but also make single data.frame
+#' tabl_data(tabl(ss[1:3]))
 #' ## manipulate with dplyr
 #' library("dplyr")
-#' tabl(gists("minepublic")[1:10]) %>% 
+#' tabl_data(tabl(ss[1:30])) %>% 
 #'   select(id, description, owner_login) %>% 
 #'   filter(grepl("gist gist gist", description))
 #' 
@@ -23,7 +36,7 @@
 #' tabl(x[[1]])
 #' 
 #' ## many
-#' x <- sapply(c(gists(), gists()), commits)
+#' x <- sapply(gists(per_page = 100), commits)
 #' tabl(x) %>%
 #'   select(id, login, change_status.total, url) %>% 
 #'   filter(change_status.total > 50)
@@ -34,6 +47,13 @@
 #' gg <- gists()
 #' (urls <- vapply(gg, "[[", "", "html_url"))
 #' lapply(urls[1:5], as.gist) %>% tabl()
+#' 
+#' # gist with forks and history
+#' gist('1642874') %>% tabl
+#' 
+#' # gist with history, no forks
+#' gist('030adf9eaa7b9b8c280e') %>% tabl
+#' gist('c96d2e453c95d0166408') %>% tabl 
 #' }
 tabl <- function(x, ...) {
   UseMethod("tabl")
@@ -41,22 +61,52 @@ tabl <- function(x, ...) {
 
 #' @export
 tabl.gist <- function(x, ...){
-  singles <- move_cols(data.frame(null2na(x[ names(x) %in% snames ]), stringsAsFactors = FALSE), "id")
   others <- x[ !names(x) %in% snames ]
   files <- lappdf(others$files, "files")
+  files_n <- NROW(files)
+  
+  singles <- move_cols(data.frame(null2na(x[ names(x) %in% snames ]), stringsAsFactors = FALSE), "id")
+  singles <- repeat_rows(singles, files_n)
+  
   owner <- data.frame(others$owner, stringsAsFactors = FALSE)
-  owner <- if(NROW(owner) == 0) owner else setNames(owner, paste0("owner_", names(owner)))
-  forks <- lappdf(others$forks, "forks")
-  history <- lappdf(others$history, "history")
-  as_data_frame(cbind_fill(singles, files, owner, forks, history, as_df = TRUE))
+  owner <- if (NROW(owner) == 0) owner else setNames(owner, paste0("owner_", names(owner)))
+  owner <- repeat_rows(owner, files_n)
+  
+  one <- dplyr::as_data_frame(cbind_fill(singles, files, owner, as_df = TRUE))
+  
+  forks <- dplyr::as_data_frame(lappdf(others$forks, "forks"))
+  history <- dplyr::as_data_frame(lappdf(others$history, "history"))
+  
+  if (NROW(forks) == 0) forks <- NULL
+  if (NROW(history) == 0) history <- NULL
+  list(data = one, forks = forks, history = history)
+}
+
+repeat_rows <- function(x, n) {
+  x <- x[rep(1, each = n), ]
+  row.names(x) <- NULL
+  x
+}
+
+#' @export
+#' @rdname tabl
+tabl_data <- function(x) {
+  stopifnot(is(x, "list"))
+  suppressWarnings(dplyr::rbind_all(lapply(x, "[[", "data")))
 }
 
 #' @export
 tabl.list <- function(x, ...) {
-  if(any(sapply(x, class) == "list")) {
+  if (any(sapply(x, class) == "list")) {
     x <- unlist(x, recursive = FALSE)
   }
-  suppressWarnings(rbind_all(lapply(x, tabl)))
+  res <- lapply(x, tabl)
+  if (is(x[[1]], "commit")) {
+    suppressWarnings(rbind_all(res))
+  } else {
+    res
+  }
+  # suppressWarnings(rbind_all(lapply(x, tabl)))
 }
 
 #' @export
@@ -72,11 +122,11 @@ snames <- c("url","forks_url", "commits_url", "id", "git_pull_url",
             "updated_at", "description", "comments", "user", "comments_url")
 
 lappdf <- function(x, prefix = NULL) {
-  tmp <- data.frame(rbind_all(lapply(x, function(z){
-    data.frame(null2na(z), stringsAsFactors=FALSE)
-  })), stringsAsFactors=FALSE)
-  if(!is.null(prefix)){
-    if(NROW(tmp) == 0){
+  tmp <- data.frame(rbind_all(lapply(x, function(z) {
+    data.frame(null2na(z), stringsAsFactors = FALSE)
+  })), stringsAsFactors = FALSE)
+  if (!is.null(prefix)) {
+    if (NROW(tmp) == 0) {
       tmp
     } else {
       setNames( tmp, paste0(prefix, "_", names(tmp)) )
@@ -98,11 +148,13 @@ null2na <- function(w) {
 
 cbind_fill <- function(..., as_df = FALSE) {
   nm <- list(...) 
-  nm <-lapply(nm, as.matrix)
+  nm <- lapply(nm, as.matrix)
   n <- max(sapply(nm, nrow)) 
-  temp <- do.call(cbind, lapply(nm, function (x) 
-    rbind(x, matrix(, n-nrow(x), ncol(x))))) 
-  if(as_df){
+  temp <- do.call(cbind, lapply(nm, function(x) { 
+      rbind(x, matrix(, n - nrow(x), ncol(x)))
+    })
+  ) 
+  if (as_df) {
     data.frame(temp, stringsAsFactors = FALSE)
   } else {
     temp
